Package: muiMaterial
Type: Package
Title: 'Material UI' for 'shiny' Apps and 'Quarto'
Version: 0.2.0
Authors@R: 
  c(person(given = "Felix",
           family = "Luginbuhl",
           role = c("aut", "cre", "cph"),
           email = "felix.luginbuhl@protonmail.ch",
           comment = c(ORCID = "0009-0008-6625-2899")),
    person(family = "MUI",
           role = "cph",
           comment = "Copyright holder of the bundled '@mui/material', '@mui/lab', '@mui/system' and '@mui/utils' JavaScript libraries"),
    person(family = "Emotion team",
           role = "cph",
           comment = "Copyright holder of the bundled '@emotion/react' and '@emotion/styled' JavaScript libraries"),
    person(family = "Meta Platforms, Inc. and affiliates",
           role = "cph",
           comment = "Copyright holder of the bundled 'react-is' JavaScript library; 'react' and 'react-dom' are declared as peer dependencies and provided at runtime by 'shiny.react'"))
Maintainer: Felix Luginbuhl <felix.luginbuhl@protonmail.ch>
Description: 
  Wraps the 'Material UI' React components <https://mui.com/> for use in R, 'shiny'
  applications and 'quarto' documents, including inputs, layouts, navigation, and
  surfaces. All inputs come with R usage examples.
License: MIT + file LICENSE
Encoding: UTF-8
Language: en-US
Depends: R (>= 4.1)
Imports: checkmate (>= 2.0.0), htmltools (>= 0.5.0), shiny (>= 1.7.0),
        shiny.react (>= 0.4.0)
Suggests: knitr, reactRouter (>= 0.2.0), shiny.router, testthat (>=
        3.0.0)
RoxygenNote: 7.3.3
URL: https://felixluginbuhl.com/muiMaterial/
BugReports: https://github.com/lgnbhl/muiMaterial/issues
Config/testthat/edition: 3
Collate: 'aaa-utils.R' 'ThemeProvider.R' 'browse.R'
        'components-extra.R' 'components.R' 'docs-templates.R'
        'documentation.R' 'inputs.R' 'muiMaterial-package.R'
        'muiMaterialDependency.R' 'muiMaterialExample.R'
        'muiMaterialPage.R' 'reexports.R' 'static-tabs.R' 'triggerId.R'
NeedsCompilation: no
Packaged: 2026-06-04 15:05:54 UTC; felix
Author: Felix Luginbuhl [aut, cre, cph] (ORCID:
    <https://orcid.org/0009-0008-6625-2899>),
  MUI [cph] (Copyright holder of the bundled '@mui/material', '@mui/lab',
    '@mui/system' and '@mui/utils' JavaScript libraries),
  Emotion team [cph] (Copyright holder of the bundled '@emotion/react'
    and '@emotion/styled' JavaScript libraries),
  Meta Platforms, Inc. and affiliates [cph] (Copyright holder of the
    bundled 'react-is' JavaScript library; 'react' and 'react-dom' are
    declared as peer dependencies and provided at runtime by
    'shiny.react')
Repository: CRAN
Date/Publication: 2026-06-04 15:20:01 UTC
Built: R 4.5.2; ; 2026-06-04 19:00:09 UTC; unix
